/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayIcon from '@clayui/icon';
import {LinkOrButton} from '@clayui/shared';
import PropTypes from 'prop-types';
import React from 'react';

import {formatActionURL} from '../utils/index';
import {actionsBasePropTypes} from './Actions';

function QuickActions({actions, itemData, itemId, onClick}) {
	return (
		<div className="quick-action-menu">
			{actions.map((action) => {
				return (
					<LinkOrButton
						aria-label={action.label || action.icon}
						className="component-action quick-action-item"
						displayType="unstyled"
						href={
							action.href &&
							formatActionURL(action.href, itemData)
						}
						key={action.data?.id || action.label}
						monospaced={false}
						onClick={(event) =>
							onClick({
								action,
								event,
								itemData,
								itemId,
							})
						}
						symbol={action.icon}
						title={action.label}
					>
						<ClayIcon symbol={action.icon} />
					</LinkOrButton>
				);
			})}
		</div>
	);
}

QuickActions.propTypes = {
	...actionsBasePropTypes,
	onClick: PropTypes.func.isRequired,
};

export default QuickActions;
